==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ms/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di laman web',
    'a_user_requested' => 'Seorang pengguna telah meminta item di laman web',
    'accessory_name' => 'Nama Aksesori:',
    'additional_notes' => 'Nota tambahan:',
    'admin_has_created' => 'Pentadbir telah membuat akaun untuk anda di: laman web web.',
    'asset' => 'Aset:',
    'asset_name' => 'Nama Aset:',
    'asset_requested' => 'Aset diminta',
    'asset_tag' => 'Tag Aset:',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Selamat sejahtera,',
    'canceled' => 'Dibatalkan:',
    'checkin_date' => 'Tarikh Semakan:',
    'checkout_date' => 'Tarikh Semakan:',
    'click_to_confirm' => 'Sila klik pada pautan berikut untuk mengesahkan akaun web anda:',
    'click_on_the_link_accessory' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aset tersebut.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY semasa',
    'Days' => 'Hari',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tarikh Semak Yang Diharapkan:',
    'expires' => 'Tamat tempoh',
    'Expiring_Assets_Report' => 'Laporan Aset Tamat.',
    'Expiring_Licenses_Report' => 'Laporan Lesen Berakhir.',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Saya telah membaca dan bersetuju dengan terma penggunaan, dan telah menerima item ini.',
    'item' => 'Perkara:',
    'Item_Request_Canceled' => 'Permintaan Item Dibatalkan',
    'Item_Requested' => 'Item yang diminta',
    'link_to_update_password' => 'Sila klik pada pautan berikut untuk mengemas kini kata laluan web anda:',
    'login_first_admin' => 'Masuk ke pemasangan Snipe-IT baru anda menggunakan kelayakan di bawah ini:',
    'login' => 'Log masuk:',
    'Low_Inventory_Report' => 'Laporan Inventori Rendah',
    'min_QTY' => 'QTY min',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa di bawah nama anda, butiran di bawah.',
    'password' => 'Kata Laluan:',
    'password_reset' => 'Memadam kata laluan',

    'read_the_terms' => 'Sila baca terma penggunaan di bawah.',
    'read_the_terms_and_click' => 'Sila baca terma penggunaan di bawah, dan klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda membaca dan bersetuju dengan terma penggunaan, dan telah menerima aset tersebut.',
    'requested' => 'Diminta:',
    'reset_link' => 'Pautan Semula Kata Laluan Anda',
    'reset_password' => 'Klik di sini untuk menetapkan semula kata laluan anda:',
    'serial' => 'Siri',
    'supplier' => 'Pembekal',
    'tag' => 'Tag',
    'test_email' => 'Uji E-mel dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Sistem Pengurusan Asset Snipe-IT. Jika anda mendapat ini, mel sedang berfungsi :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'low_inventory_alert' => 'Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah. Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah.',
    'assets_warrantee_alert' => 'Terdapat :count aset yang akan tamat tempoh waranti dalam :threshold hari.|Terdapat :count aset yang akan tamat dalam tempoh waranti dalam :threshold hari.',
    'license_expiring_alert' => 'Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.|Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.',
    'to_reset' => 'Untuk menetapkan semula kata laluan web anda, lengkapkan borang ini:',
    'type' => 'Taipkan',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat datang ke: web!',
    'your_credentials' => 'Kredensial Snipe-IT anda',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ms/mail.php <==
<?php

return [
    'a_user_canceled' => 'Pengguna telah membatalkan permintaan item di laman web',
    'a_user_requested' => 'Seorang pengguna telah meminta item di laman web',
    'accessory_name' => 'Nama Aksesori:',
    'additional_notes' => 'Nota tambahan:',
    'admin_has_created' => 'Pentadbir telah membuat akaun untuk anda di: laman web web.',
    'asset' => 'Aset:',
    'asset_name' => 'Nama Aset:',
    'asset_requested' => 'Aset diminta',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Ditugaskan untuk',
    'best_regards' => 'Selamat sejahtera,',
    'canceled' => 'Dibatalkan:',
    'checkin_date' => 'Tarikh Semakan:',
    'checkout_date' => 'Tarikh Semakan:',
    'click_to_confirm' => 'Sila klik pada pautan berikut untuk mengesahkan akaun web anda:',
    'click_on_the_link_accessory' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aksesori.',
    'click_on_the_link_asset' => 'Sila klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda telah menerima aset tersebut.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'QTY semasa',
    'Days' => 'Hari',
    'days' => 'Hari',
    'expecting_checkin_date' => 'Tarikh Semak Yang Diharapkan:',
    'expires' => 'Tamat tempoh',
    'Expiring_Assets_Report' => 'Laporan Aset Tamat.',
    'Expiring_Licenses_Report' => 'Laporan Lesen Berakhir.',
    'hello' => 'Hello',
    'hi' => 'Hi',
    'i_have_read' => 'Saya telah membaca dan bersetuju dengan terma penggunaan, dan telah menerima item ini.',
    'item' => 'Perkara:',
    'Item_Request_Canceled' => 'Permintaan Item Dibatalkan',
    'Item_Requested' => 'Item yang diminta',
    'link_to_update_password' => 'Sila klik pada pautan berikut untuk mengemas kini kata laluan web anda:',
    'login_first_admin' => 'Masuk ke pemasangan Snipe-IT baru anda menggunakan kelayakan di bawah ini:',
    'login' => 'Log masuk:',
    'Low_Inventory_Report' => 'Laporan Inventori Rendah',
    'min_QTY' => 'QTY min',
    'name' => 'Nama',
    'new_item_checked' => 'Item baru telah diperiksa di bawah nama anda, butiran di bawah.',
    'password' => 'Kata Laluan:',
    'password_reset' => 'Memadam kata laluan',

    'read_the_terms' => 'Sila baca terma penggunaan di bawah.',
    'read_the_terms_and_click' => 'Sila baca terma penggunaan di bawah, dan klik pada pautan di bahagian bawah untuk mengesahkan bahawa anda membaca dan bersetuju dengan terma penggunaan, dan telah menerima aset tersebut.',
    'requested' => 'Diminta:',
    'reset_link' => 'Pautan Semula Kata Laluan Anda',
    'reset_password' => 'Klik di sini untuk menetapkan semula kata laluan anda:',
    'serial' => 'Siri',
    'supplier' => 'Pembekal',
    'tag' => 'Tag',
    'test_email' => 'Uji E-mel dari Snipe-IT',
    'test_mail_text' => 'Ini adalah ujian dari Sistem Pengurusan Asset Snipe-IT. Jika anda mendapat ini, mel sedang berfungsi :)',
    'the_following_item' => 'Item berikut telah diperiksa:',
    'low_inventory_alert' => 'Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah. Terdapat :count item yang berada di bawah inventori minimum atau akan menjadi rendah.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.|Terdapat :count lesen yang akan tamat dalam tempoh :threshold hari.',
    'to_reset' => 'Untuk menetapkan semula kata laluan web anda, lengkapkan borang ini:',
    'type' => 'Taipkan',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Pengguna',
    'username' => 'Nama Pengguna',
    'welcome' => 'Selamat datang: nama',
    'welcome_to' => 'Selamat datang ke: web!',
    'your_credentials' => 'Kredensial Snipe-IT anda',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
